@@ -1,7 +1,8 @@
 use log::*;
+
 pub fn main() {
     #[cfg(feature = "logging")]
-    wolf_engine::initialize_logging(LevelFilter::Debug);
+    wolf_engine::logging::initialize_logging(LevelFilter::Debug);
 
     info!("Hello, world!");
     debug!("This is some debug information.");
